### 本程序的技术博客
### http://blog.mangolovecarrot.net/2025/01/18/pico-01

from machine import Pin, SPI
from max7219 import max7219
import time

# SPI接口设置
spi = SPI(1, baudrate=10000000, polarity=0, phase=0)
cs = Pin(0, Pin.OUT)

# 初始化MAX7219
matrix = max7219.Matrix8x8(spi, cs, 1)
matrix.brightness(0)

# 定义数字0-9的图案
digits = [
    [0x3E, 0x63, 0x67, 0x6F, 0x7B, 0x73, 0x63, 0x3E],  # 0
    [0x0C, 0x1C, 0x3C, 0x0C, 0x0C, 0x0C, 0x0C, 0x3F],  # 1
    [0x3E, 0x63, 0x03, 0x0E, 0x3C, 0x70, 0x63, 0x7F],  # 2
    [0x3E, 0x63, 0x03, 0x1E, 0x03, 0x03, 0x63, 0x3E],  # 3
    [0x06, 0x0E, 0x1E, 0x36, 0x66, 0x7F, 0x06, 0x06],  # 4
    [0x7F, 0x60, 0x7E, 0x03, 0x03, 0x03, 0x63, 0x3E],  # 5
    [0x1E, 0x30, 0x60, 0x7E, 0x63, 0x63, 0x63, 0x3E],  # 6
    [0x7F, 0x63, 0x06, 0x0C, 0x18, 0x18, 0x18, 0x18],  # 7
    [0x3E, 0x63, 0x63, 0x3E, 0x63, 0x63, 0x63, 0x3E],  # 8
    [0x3E, 0x63, 0x63, 0x63, 0x3F, 0x03, 0x06, 0x3C]   # 9
]

# 显示方向（1=0°，2=90°，3=180°，4=270°）
display_direction = 2

# 最大亮度（0-15）
max_brightness = 4

# 图案旋转函数
def rotate_digit(digit, direction):
    rotated = [[0]*8 for _ in range(8)]
    for y in range(8):
        for x in range(8):
            bit = (digit[y] >> (7 - x)) & 1
            if direction == 1:
                rotated[y][x] = bit
            elif direction == 2:
                rotated[x][7 - y] = bit
            elif direction == 3:
                rotated[7 - y][7 - x] = bit
            elif direction == 4:
                rotated[7 - x][y] = bit
    return rotated

# 呼吸灯效果
def breathing_effect():
    for b in range(0, max_brightness + 1):
        matrix.brightness(b)
        time.sleep(0.05)
    for b in range(max_brightness, -1, -1):
        matrix.brightness(b)
        time.sleep(0.05)

# 循环显示数字0-9
while True:
    for digit in digits:
        matrix.fill(0)
        rotated_digit = rotate_digit(digit, display_direction)
        for y in range(8):
            for x in range(8):
                matrix.pixel(x, y, rotated_digit[y][x])
        matrix.show()
        start_time = time.ticks_ms()
        while time.ticks_diff(time.ticks_ms(), start_time) < 1000:
            breathing_effect()

